@@ -3,7 +3,10 @@
 
 import logging
 import sys
+import tempfile
 import time
+from pathlib import Path
+
 import pyLSV2
 
 logging.basicConfig(level=logging.DEBUG)
@@ -57,4 +60,31 @@ if __name__ == "__main__":
     con.set_keyboard_access(True)
     con.logout(pyLSV2.LOGIN_MONITOR)
 
+    # demo for reading the current tool with fallback if it is not supported by control
+    t_info = con.get_spindle_tool_status()
+    if t_info is not False:
+        print('Current tool number {Number}.{Index} with Axis {Axis} Length {Length} Radius {Radius}'.format(**t_info))
+    else:
+        print('Direct reading to current tool not supported for this control type. using backup strategy')
+        if con.is_tnc():
+            pocket_table_path = 'TNC:/table/tool_p.tch'
+            transfer_binary = True
+            spindel_lable = '0.0'
+        elif con.is_itnc():
+            pocket_table_path = 'TNC:/TOOL_P.TCH'
+            transfer_binary = False
+            spindel_lable = '0'
+        else:
+            pocket_table_path = 'TNC:/table/ToolAllo.tch'
+            transfer_binary = True
+            spindel_lable = '0.0'
+
+        with tempfile.TemporaryDirectory(suffix=None, prefix='pyLSV2_') as tmp_dir_name:
+            local_recive_path = Path(tmp_dir_name).joinpath('tool_p.tch')
+            con.recive_file(local_path=str(local_recive_path), remote_path=pocket_table_path, binary_mode=transfer_binary)
+            tr = pyLSV2.TableReader()
+            pockets = tr.parse_table(local_recive_path)
+            spindel = list(filter(lambda pocket: pocket['P'] == spindel_lable, pockets))[0]
+            print('Current tool number {T} with name {TNAME}'.format(**spindel))
+
     con.disconnect()
